@@ -4,6 +4,8 @@ The class that handles parsing input.
 :author: Doug Skrypa
 """
 
+from __future__ import annotations
+
 import logging
 from collections import deque
 from typing import TYPE_CHECKING, Optional, Union, Any, Deque, List
@@ -11,7 +13,7 @@ from typing import TYPE_CHECKING, Optional, Union, Any, Deque, List
 from .context import ctx
 from .exceptions import UsageError, ParamUsageError, NoSuchOption, MissingArgument, ParamsMissing
 from .exceptions import CommandDefinitionError, Backtrack, UnsupportedAction
-from .parameters import BaseOption, Parameter, BasePositional, BasicActionMixin
+from .parameters.base import BasicActionMixin, Parameter, BasePositional, BaseOption
 
 if TYPE_CHECKING:
     from .core import CommandType
@@ -33,19 +35,20 @@ class CommandParser:
         self.positionals = ctx.params.positionals.copy()
 
     @classmethod
-    def parse_args(cls) -> Optional['CommandType']:
+    def parse_args(cls) -> Optional[CommandType]:
         try:
             return cls.__parse_args()
         except UsageError:
             ctx.failed = True
             if not ctx.parsed_always_available_action_flags:
                 raise
+            return None
         except Exception:
             ctx.failed = True
             raise
 
     @classmethod
-    def __parse_args(cls) -> Optional['CommandType']:
+    def __parse_args(cls) -> Optional[CommandType]:
         params = ctx.params
         sub_cmd_param = params.sub_command
         if sub_cmd_param is not None and not sub_cmd_param.choices:
@@ -75,7 +78,7 @@ class CommandParser:
         return None
 
     @classmethod
-    def _validate_groups(cls, params: 'CommandParameters'):
+    def _validate_groups(cls, params: CommandParameters):
         exc = None
         for group in params.groups:
             try:
@@ -93,7 +96,7 @@ class CommandParser:
         while arg_deque:
             arg = arg_deque.popleft()
             if arg == '--':
-                if ctx.params.find_nested_pass_thru():
+                if ctx.params.find_nested_pass_thru():  # pylint: disable=R1723
                     self.deferred.append(arg)
                     self.deferred.extend(arg_deque)
                     break
@@ -124,9 +127,8 @@ class CommandParser:
         if pass_thru is not None:
             try:
                 separator_pos = remaining.index('--')
-            except ValueError as e:
-                if pass_thru.required:
-                    raise MissingArgument(pass_thru, "missing pass thru args separated from others with '--'") from e
+            except ValueError:
+                pass  # If required, it's handled by the normal missing param handler
             else:
                 remainder_start = separator_pos + 1
                 pass_thru.take_action(remaining[remainder_start:])
